@@ -21,7 +21,6 @@ from datetime import datetime, timedelta
 
 from demyst.common.config import load_config
 from demyst.common.connectors import Connectors, DemystConnectorError
-from demyst.common.track import track_function
 from demyst.common.pii import PII_REGEX
 from demyst.analytics.shiny import progressbar
 from demyst.analytics.shiny import generatehandlerbutton
@@ -544,10 +543,6 @@ class Analytics(object):
 
     def input_file(self, table_name, row_limit=None, filters=None):
         """Provides filtered input file that can be used for search or enrichment."""
-        return track_function(lambda: self.__do_input_file(table_name, row_limit, filters),
-                              self.__config, "API : Python : Rosefish Export")
-
-    def __do_input_file(self, table_name, row_limit=None, filters=None):
         params = { "table_name": table_name }
         if(row_limit):
             params["row_limit"] = row_limit
@@ -563,11 +558,6 @@ class Analytics(object):
         return(input_file_df)
 
     def input_files(self, headers=None):
-        """Lists the various sample input entities available."""
-        return track_function(lambda: self.__do_input_files(headers),
-                              self.__config, "API : Python : Rosefish Product List")
-
-    def __do_input_files(self, headers):
         table_providers = self.__config.auth_get(self.__config.get("MANTA_URL") + "list_hosted_inputs").json()
         if(headers):
             filtered_providers = []
@@ -582,10 +572,6 @@ class Analytics(object):
 
     def input_file_headers(self, table_name):
         """Returns information about the columns of an input file."""
-        return track_function(lambda: self.__do_input_file_headers(table_name),
-                              self.__config, "API : Python : Rosefish Product Headers")
-
-    def __do_input_file_headers(self, table_name):
         table_providers = self.__config.auth_get(self.__config.get("MANTA_URL") + "list_hosted_inputs").json()
         provider_names = list(map(lambda provider: provider['name'], table_providers))
         if table_name in provider_names:
@@ -597,25 +583,14 @@ class Analytics(object):
 
     def list_stats_products(self):
         """Returns a list of all data products for which stats are available."""
-        return track_function(lambda: self.__do_list_stats_products(),
-                              self.__config, "API : Python : Hogfish Product List")
-
-    def __do_list_stats_products(self):
         return self.__config.auth_get(self.__config.get("MANTA_URL") + "hogfish_providers").json()
 
-
     def product_stats(self, provider_names=[], all_products=False):
         """
         Accepts an array of data products as an argument and returns a
         dataframe of performance metrics and metadata for each of
         those products' fields.
         """
-        return track_function(lambda: self.__do_product_stats(provider_names, all_products),
-                              self.__config, "API : Python : Hogfish Stats",
-                              { "provider_names": provider_names,
-                                "all_products": all_products })
-
-    def __do_product_stats(self, provider_names, all_products):
         res = []
         if all_products:
             provider_names = self.list_stats_products()
@@ -733,11 +708,6 @@ class Analytics(object):
 
     def data_function_append(self, name, inputs_dframe):
         """Calls a data function and augments the input dataframe with returned results."""
-        return track_function(lambda: self.__do_data_function_append(name, inputs_dframe),
-                              self.__config, "API : Python : Data Function Append",
-                              { "name": name })
-
-    def __do_data_function_append(self, name, inputs_dframe):
         # TODO: call async
         non_nan_dframe = inputs_dframe.replace(np.nan, '', regex=True)
         output = [None] * len(non_nan_dframe)
@@ -782,39 +752,17 @@ class Analytics(object):
         """
         if hosted_input:
             inputs = self.input_file(hosted_input)
-        return track_function(lambda: self.__do_enrich(providers,
-                                                     inputs,
-                                                     validate=validate,
-                                                     all_updates=all_updates,
-                                                     fixed_list_size=fixed_list_size),
-                              self.__config, "API : Python : Enrich",
-                              { "provider_names": providers,
-                                "num_rows": len(inputs) })
-
-    def enrich_credits(self, providers, inputs, validate=True):
-        """Prints information about the cost of running an enrichment."""
-        self.__check_provider_names(providers)
-        inputs = self.__stringify_dframe(inputs)
-        if (validate):
-            if (not self.__validate_providers(providers, inputs)):
-                return None
-        provider_ids = [self.__config.provider_name_to_id(name) for name in providers]
-        num_rows = len(inputs)
-        url_params = { "rows": num_rows, "providers[]": provider_ids }
-        path = "table_providers/calculate_credit_cost?" + urlencode(url_params, doseq=True)
-        return self.__config.auth_get(self.__config.get("MANTA_URL") + path).json()["total_cost"]
-
-    def __do_enrich(self, providers, inputs, validate=True, all_updates=False, fixed_list_size=1):
         limit = 20
         if len(providers) > limit:
             raise RuntimeError("Only " + str(limit) + " providers are allowed.")
-        self.__check_provider_names(providers)
+        provider_names = self.__providers_to_provider_names(providers)
+        self.__check_provider_names(provider_names)
         print("Starting enrichment...")
         if len(inputs) == 0:
             raise RuntimeError("Inputs dataframe is empty")
         inputs = self.__stringify_dframe(inputs)
         if (validate):
-            if (not self.__validate_providers(providers, inputs)):
+            if (not self.__validate_providers(provider_names, inputs)):
                 raise RuntimeError("Validation failed")
         fd, temp_path = tempfile.mkstemp()
         try:
@@ -828,9 +776,17 @@ class Analytics(object):
                 #print("Warning: couldn't delete temporary file: " + temp_path, file=sys.stderr)
                 pass
 
+    def __providers_to_provider_names(self, providers):
+        def provider_to_provider_name(p):
+            if isinstance(p, str):
+                return p
+            else:
+                return p["name"]
+        return [provider_to_provider_name(p) for p in providers]
+
     def __enrich_csv(self, providers, csv_file, columns, all_updates, fixed_list_size):
         num_rows = self.__count_lines_in_file(csv_file)
-        self.__abort_if_not_enough_caps(providers, num_rows)
+        self.__abort_if_not_enough_caps(self.__providers_to_provider_names(providers), num_rows)
         region_id = self.__find_region_id(self.__config.get("REGION"))
         dict = self.__get_presigned_url_and_s3_object_key(region_id)
         url = dict["presigned_url"]
@@ -875,7 +831,7 @@ class Analytics(object):
         raise RuntimeError("Region not found: " + region_code)
 
     def __run_batch(self, providers, input_id, region_id, all_updates, fixed_list_size):
-        provider_ids = [self.__config.provider_name_to_version_id(name) for name in providers]
+        provider_ids = [self.__config.provider_to_version_id(p) for p in providers]
         if self.__config.has("API_KEY"):
             username = self.__config.get("API_KEY")[:8]
         else:
@@ -926,6 +882,20 @@ class Analytics(object):
             cap_items = self.__get_cap_items(provider_names)
             self.__check_cap_items(cap_items, num_rows)
 
+
+    def enrich_credits(self, providers, inputs, validate=True):
+        """Prints information about the cost of running an enrichment."""
+        self.__check_provider_names(providers)
+        inputs = self.__stringify_dframe(inputs)
+        if (validate):
+            if (not self.__validate_providers(providers, inputs)):
+                return None
+        provider_ids = [self.__config.provider_name_to_id(name) for name in providers]
+        num_rows = len(inputs)
+        url_params = { "rows": num_rows, "providers[]": provider_ids }
+        path = "table_providers/calculate_credit_cost?" + urlencode(url_params, doseq=True)
+        return self.__config.auth_get(self.__config.get("MANTA_URL") + path).json()["total_cost"]
+
     def __get_cap_items(self, provider_names):
         items = []
         page = 1
@@ -1024,11 +994,6 @@ class Analytics(object):
         Downloads the augumented data of an enrichment job and returns
         the resulting dataframe.
         """
-        return track_function(lambda: self.__do_enrich_download(id, providers=providers, block_until_complete=block_until_complete),
-                              self.__config, "API : Python : Download",
-                              { "job_id": id })
-
-    def __do_enrich_download(self, id, providers=[], block_until_complete=True):
         fd, temp_path = tempfile.mkstemp()
         try:
             # Overwrite=True is needed because temp file gets created above
@@ -1143,11 +1108,6 @@ class Analytics(object):
             inputs = self.input_file(hosted_input)
         if isinstance(inputs, pd.DataFrame):
             inputs = list(inputs)
-        return track_function(lambda: self.__do_search(inputs=inputs, tags=tags, view=view, strict=strict),
-                              self.__config, "API : Python : Search",
-                              { "tags": tags, "view": view, "inputs": inputs })
-
-    def __do_search(self, inputs=None, tags=None, view="html", strict=False):
         if isinstance(inputs, list) or isinstance(tags, list):
             params = {
                 'inputs[]': inputs,
@@ -1567,28 +1527,20 @@ class Analytics(object):
         """Report provides you with statistical data at product and attribute level."""
         return report(enriched, columns=columns)
 
-    def __do_table_list(self):
+    def table_list(self):
+        """Lists the hosted tables available for export."""
         url = self.__config.get("MANTA_URL") + "v1/hosted_tables/"
         resp = self.__config.auth_get(url).json()
         return [table["name"] for table in resp]
 
-    def table_list(self):
-        """Lists the hosted tables available for export."""
-        return track_function(lambda: self.__do_table_list(),
-                              self.__config, "API : Python : Table List")
-
-    def __do_table_details(self, table_name):
+    def table_details(self, table_name):
+        """Shows detail about a hosted table."""
         show_url = self.__config.get("MANTA_URL") + "v1/hosted_tables/{}".format(table_name)
         show_resp = self.__config.auth_get(show_url).json()
         return show_resp
 
-
-    def table_details(self, table_name):
-        """Shows detail about a hosted table."""
-        return track_function(lambda: self.__do_table_details(table_name),
-                              self.__config, "API : Python : Table Details")
-
-    def __do_table_filter_list(self, table_name):
+    def table_filter_list(self, table_name):
+        """Shows filters for a hosted table."""
         show_url = self.__config.get("MANTA_URL") + "v1/hosted_tables/{}".format(table_name)
         show_resp = self.__config.auth_get(show_url).json()
         indices = show_resp["blackbelly_table_indices"]
@@ -1598,23 +1550,14 @@ class Analytics(object):
             index_res = {}
             name = index["column_names"][0]
             column = [column for column in columns if column['name'] == name]
-            index_res["type"] = column[0]["primitive_type"]
+            index_res["type"] = column[0]["demyst_type_name"]
             index_res["name"] = name
             res.append(index_res)
         deduped =  [dict(t) for t in {tuple(d.items()) for d in res}]
         return deduped
 
-    def table_filter_list(self, table_name):
-        """Shows filters for a hosted table."""
-        return track_function(lambda: self.__do_table_filter_list(table_name),
-                              self.__config, "API : Python : Table Filter List")
-
     def table_export_job(self, table_name, filters):
         """Exports slice of file."""
-        return track_function(lambda: self.__do_table_export_job(table_name, filters),
-                              self.__config, "API : Python : Table Export Job Creation")
-
-    def __do_table_export_job(self,table_name,filters):
         show_url = self.__config.get("MANTA_URL") + "v1/hosted_tables/{}".format(table_name)
         show_resp = self.__config.auth_get(show_url).json()
         table_id = show_resp["id"]
@@ -1637,10 +1580,6 @@ class Analytics(object):
 
     def table_export_download(self,export_id, file_path):
         """Downloads and tracks progress of export job."""
-        return track_function(lambda: self.__do_table_export_download(export_id, file_path),
-                              self.__config, "API : Python : Table Export Job Download")
-
-    def __do_table_export_download(self, export_id, file_path):
         export_url = self.__config.get("MANTA_URL") + "v1/hosted_table_exports/{}".format(export_id)
         export = self.__config.auth_get(export_url).json()
         table_url = self.__config.get("MANTA_URL") + "v1/hosted_tables/{}".format(export["blackbelly_table_id"])
